..
    SPDX-FileCopyrightText: 2024 Alec Delaney
    SPDX-License-Identifier: GPL-3.0-or-later

.. include:: ../README.rst

Table of Contents
=================

.. toctree::

    self

.. toctree::
    :caption: Library API
    :maxdepth: 4

    api
    api_fields
    api_app
